0.1.3
-----
* Jasmine compatibility; important fixes (Thanks to [logeen](https://github.com/logeen))
   * Matcher toBe must check also type otherwise expect(True).toBe(1) passes.
   * Matcher toEqual must be implemented differently than toBe.
   * Matchers toBeTruthy and toBeFalsy must perform "soft" checking otherwise expect(1).toBeTruthy() and expect(0).toBeFalsy() don't pass.
   * Matcher toRaise should be able to check advanced exception objects otherwise you can check only exception message but not for example exception code attribute.
   * Spy callThrough must work with functions that take arguments.
   * Spy callFake should work with fake functions that take arguments.

0.1.2
-----
* Tracking spy call orders and added toHaveBeenCalledBefore matcher

0.1.1
------
* Chaining mocks
* Explicit spy configuration

0.1.0
-----
* Spy methods
* Spy objects
* expect matchers
* Custom matchers
* Cleaning up spies